@@ -1,5 +1,5 @@
 import tkinter as tk
-import tkinter.ttk as ttk
+import ttkbootstrap as ttk
 
 
 class BaseTopLevelWidget(tk.Toplevel):
@@ -28,20 +28,18 @@ class BaseTopLevelWidget(tk.Toplevel):
             self.rowconfigure(2, weight=0)
             self.lift()
 
-        # Widgets
+        # Label configuration
         if True:
             self.label = ttk.Label(self, text=message, justify='left', padding=5)
             self.label.grid(row=0, column=0, columnspan=3, sticky='nsew')
-
-            separator = ttk.Separator(self, orient='horizontal', style='secondary.Horizontal.TSeparator')
-            separator.grid(row=1, column=0, columnspan=3, sticky='nsew')
-
-            self.control_var = tk.IntVar(value=0)
-
-            if self.label.winfo_reqwidth() > self.minsize()[0]:
+            if self.label.winfo_reqwidth() > self.minsize()[0] - 50:
                 self.minsize(self.label.winfo_reqwidth() + 20, 120)
                 self.update()
 
+        # Separator configuration
+            separator = ttk.Separator(self, orient='horizontal', style='secondary.Horizontal.TSeparator')
+            separator.grid(row=1, column=0, columnspan=3, sticky='nsew')
+
         # Determine relative position
         if True:
             position_x = parent.winfo_x()
@@ -56,6 +54,9 @@ class BaseTopLevelWidget(tk.Toplevel):
             self.geometry('%dx%d+%d+%d' % (local_width, local_height, final_position[0], final_position[1]))
             self.grab_set()
 
+        # Control variable
+        self.control_var = tk.IntVar(value=0)
+
     def adjust_var(self, option):
         self.control_var.set(option)
         self.destroy()
@@ -74,18 +75,24 @@ class OkCancelBox(BaseTopLevelWidget):
         parent: widget over which the progress bar will be positioned
         icon_path: path to the icon for the widget
         title: title message for the widget
-        message = text to be shown as an alert to the user
+        message: text to be shown as an alert to the user
+        language: language for the buttons text
     """
 
-    def __init__(self, parent, icon_path, title, message):
+    def __init__(self, parent, icon_path, title, message, language='en'):
 
         super().__init__(parent, icon_path, title, message)
 
-        cancel_button = ttk.Button(self, text="CANCEL", command=lambda: self.adjust_var(0), width=8,
+        if language == 'br':
+            cancel_text, ok_text = 'CANCELAR', 'OK'
+        else:
+            cancel_text, ok_text = 'CANCEL', 'OK'
+
+        cancel_button = ttk.Button(self, text=cancel_text, command=lambda: self.adjust_var(0), width=8,
                                    style='secondary.TButton')
         cancel_button.grid(row=2, column=1, sticky='nsew', pady=5)
 
-        ok_button = ttk.Button(self, text="OK", command=lambda: self.adjust_var(1), width=8,
+        ok_button = ttk.Button(self, text=ok_text, command=lambda: self.adjust_var(1), width=8,
                                style='primary.TButton')
         ok_button.grid(row=2, column=2, sticky='nsew', padx=5, pady=5)
 
@@ -97,17 +104,23 @@ class YesNoBox(BaseTopLevelWidget):
         parent: widget over which the progress bar will be positioned
         icon_path: path to the icon for the widget
         title: title message for the widget
-        message = text to be shown as an alert to the user
+        message: text to be shown as an alert to the user
+        language: language for the buttons text
     """
 
-    def __init__(self, parent, icon_path, title, message):
+    def __init__(self, parent, icon_path, title, message, language='en'):
 
         super().__init__(parent, icon_path, title, message)
 
-        no_button = ttk.Button(self, text="NO", command=lambda: self.adjust_var(0), width=8,
+        if language == 'br':
+            no_text, yes_text = 'NÃO', 'SIM'
+        else:
+            no_text, yes_text = 'NO', 'YES'
+
+        no_button = ttk.Button(self, text=no_text, command=lambda: self.adjust_var(0), width=8,
                                style='secondary.TButton')
         no_button.grid(row=2, column=1, sticky='nsew', pady=5)
-        yes_button = ttk.Button(self, text="YES", command=lambda: self.adjust_var(1), width=8,
+        yes_button = ttk.Button(self, text=yes_text, command=lambda: self.adjust_var(1), width=8,
                                 style='primary.TButton')
         yes_button.grid(row=2, column=2, sticky='nsew', padx=5, pady=5)
 
@@ -115,16 +128,18 @@ class YesNoBox(BaseTopLevelWidget):
 class WarningBox(BaseTopLevelWidget):
     """
     Creates a message box with the same style as the main application
-        Input:
+    Input:
         parent: widget over which the progress bar will be positioned
         icon_path: path to the icon for the widget
         title: title message for the widget
-        message = text to be shown as an alert to the user
+        message: text to be shown as an alert to the user
+        language: language for the buttons text
     """
 
-    def __init__(self, parent, icon_path, title, message):
+    def __init__(self, parent, icon_path, title, message, language='en'):
 
         super().__init__(parent, icon_path, title, message)
+
         self.label.config(style='danger.TLabel')
         ok_button = ttk.Button(self, text="OK", command=lambda: self.destroy(), width=8,
                                style='danger.TButton')
@@ -138,10 +153,11 @@ class SuccessBox(BaseTopLevelWidget):
         parent: widget over which the progress bar will be positioned
         icon_path: path to the icon for the widget
         title: title message for the widget
-        message = text to be shown as an alert to the user
+        message: text to be shown as an alert to the user
+        language: language for the buttons text
     """
 
-    def __init__(self, parent, icon_path, title, message):
+    def __init__(self, parent, icon_path, title, message, language='en'):
 
         super().__init__(parent, icon_path, title, message)
         ok_button = ttk.Button(self, text="OK", command=lambda: self.destroy(), width=8,
@@ -173,10 +189,13 @@ class ProgressBar(tk.Toplevel):
             self.config(padx=10, pady=10, bd=1, relief='raised')
             self.lift()
 
-        # Message
+        # Label configuration
         if True:
-            label = ttk.Label(self, text=message, padding=10, wraplength=300)
-            label.grid(row=0, column=0, sticky='nsew')
+            self.label = ttk.Label(self, text=message, justify='left', padding=10)
+            self.label.grid(row=0, column=0, sticky='nsew')
+            if self.label.winfo_reqwidth() > self.minsize()[0]:
+                self.minsize(self.label.winfo_reqwidth() + 20, 100)
+                self.update()
 
         # Progress bar
         if True:
@@ -213,7 +232,7 @@ class ProgressBar(tk.Toplevel):
 
 
 class Tooltip:
-    """ It creates a tooltip for a given widget as the mouse goes on it. """
+    """ It creates a tooltip window for a given widget as the mouse goes over it. """
 
     def __init__(self, widget, text='widget info', bg='#FFFF8B', fg='black', wait_time=500, wrap_length=250):
 
@@ -226,6 +245,7 @@ class Tooltip:
 
         self.widget.bind("<Enter>", self._enter)
         self.widget.bind("<Leave>", self._leave)
+        self.widget.bind("<Motion>", self._move_tip)
         self.widget.bind("<ButtonPress>", self._leave)
         self.id = None
         self.top_level = None
@@ -237,6 +257,12 @@ class Tooltip:
         self.unschedule()
         self.hide()
 
+    def _move_tip(self, event=None):
+        if self.top_level:
+            x = self.widget.winfo_pointerx() + 25
+            y = self.widget.winfo_pointery() + 10
+            self.top_level.geometry(f"+{x}+{y}")
+
     def schedule(self):
         self.unschedule()
         self.id = self.widget.after(self.wait_time, self.show)
@@ -248,36 +274,12 @@ class Tooltip:
 
     def show(self):
 
-        def tip_pos_calculator(base_widget, selected_label):
+        if self.top_level:
+            return
+        x = self.widget.winfo_pointerx() + 25
+        y = self.widget.winfo_pointery() + 10
 
-            # Get the monitor's size
-            total_width, total_height = base_widget.winfo_vrootwidth(), base_widget.winfo_vrootheight()
-
-            # Tip label minimum size (plus offset)
-            width, height = (selected_label.winfo_reqwidth() + 10, selected_label.winfo_reqheight() + 6)
-
-            # Mouse position
-            mouse_x, mouse_y = base_widget.winfo_pointerxy()
-
-            # Top level initial and final positions
-            x1, y1 = mouse_x + 10, mouse_y + 6
-            x2, y2 = x1 + width, y1 + height
-
-            # Checks for horizontal position
-            if x2 > total_width:
-                x1 -= (x2 - total_width)
-            if x1 < 0:
-                x1 = 30
-
-            # Checks for vertical position
-            if y2 > total_height:
-                y1 -= (y2 - total_height)
-            if y1 < 0:
-                y1 = 30
-
-            return x1, y1
-
-        self.top_level = tk.Toplevel(self.widget)
+        self.top_level = ttk.Toplevel(self.widget, position=(x, y))
         self.top_level.wm_overrideredirect(True)
         self.top_level.rowconfigure(0, weight=1)
         self.top_level.columnconfigure(0, weight=1)
@@ -287,10 +289,6 @@ class Tooltip:
                           wraplength=self.wrap_length, style='custom.TLabel')
         label.grid(row=0, column=0, sticky='nsew', padx=1, pady=1)
 
-        x, y = tip_pos_calculator(self.widget, label)
-
-        self.top_level.geometry(f'+{x}+{y}')
-
     def hide(self):
         if self.top_level:
             self.top_level.destroy()
@@ -299,7 +297,7 @@ class Tooltip:
 
 class TimedBox(tk.Toplevel):
     """
-    Basic TopLevel Widget for Message Boxes
+    TopLevel widget for timed message boxes.
     Input:
         parent = widget over which the progress bar will be positioned
         message = text to be shown as an alert to the user
@@ -313,10 +311,7 @@ class TimedBox(tk.Toplevel):
         if True:
             super().__init__(parent)
             self.overrideredirect(True)
-            try:
-                self.time = int(time)
-            except ValueError:
-                self.time = 1
+            self.total_time_ms = 1000 * time
             self.minsize(250, 120)
             self.columnconfigure(0, weight=1)
             self.columnconfigure(1, weight=0)
@@ -338,15 +333,16 @@ class TimedBox(tk.Toplevel):
             label.grid(row=0, column=0, columnspan=2, sticky='nsew', padx=10, pady=10)
 
             self.progressbar_var = tk.DoubleVar(value=0)
-            self.progressbar = ttk.Progressbar(self, maximum=1, orient='horizontal', mode='determinate',
-                                               style=progress_bar_style, variable=self.progressbar_var)
+            self.progressbar = ttk.Progressbar(self, maximum=self.total_time_ms, orient='horizontal',
+                                               mode='determinate', style=progress_bar_style,
+                                               variable=self.progressbar_var)
             self.progressbar.grid(row=1, column=0, columnspan=2, sticky='nsew', padx=10)
 
             button = ttk.Button(self, text='CLOSE', style=button_style, command= lambda: self.destroy())
             button.grid(row=2, column=1, sticky='nsew', pady=10, padx=10)
 
             if label.winfo_reqwidth() > self.minsize()[0]:
-                self.minsize(label.winfo_reqwidth() + 20, 120)
+                self.minsize(label.winfo_reqwidth() + 40, 120)
                 self.update()
 
         # Determine relative position
@@ -365,10 +361,12 @@ class TimedBox(tk.Toplevel):
 
     def update_progress_bar(self):
 
-        steps = self.time*100
-        for i in range(steps):
-            self.after(10)
-            self.progressbar_var.set(i/steps)
+        step_number = 50
+        step = int(self.total_time_ms / step_number)
+
+        for i in range(step_number):
+            self.after(step)
+            self.progressbar_var.set((i + 1) * step)
             self.progressbar.update()
         self.destroy()
 
