@@ -1,15 +1,17 @@
-__version__ = "0.1.39"
+__version__ = "0.3.19"
 __author__ = 'Andre Mariano'
 __all__ = ['AUTOCOMPLETE_WIDGETS',
            'COMPOUND_WIDGETS',
            'CUSTOM_BUTTONS',
            'CUSTOM_FRAMES',
            'MESSAGE_BOX_WIDGETS',
-           'IMAGES']
+           'IMAGES',
+           'SCRIPTS']
 
 from .AUTOCOMPLETE_WIDGETS import AutocompleteEntryList
+from .AUTOCOMPLETE_WIDGETS import AutocompleteCombobox
+from .AUTOCOMPLETE_WIDGETS import AutocompleteLabelCombo
 
-from .COMPOUND_WIDGETS import CheckLedButton
 from .COMPOUND_WIDGETS import LabelCombo
 from .COMPOUND_WIDGETS import LabelComboButton
 from .COMPOUND_WIDGETS import LabelEntry
@@ -17,8 +19,6 @@ from .COMPOUND_WIDGETS import LabelEntryButton
 from .COMPOUND_WIDGETS import LabelEntryUnit
 from .COMPOUND_WIDGETS import LabelSpinbox
 from .COMPOUND_WIDGETS import LabelText
-from .COMPOUND_WIDGETS import LedButton
-from .COMPOUND_WIDGETS import RadioLedButton
 
 from .CUSTOM_BUTTONS import AddNewButton
 from .CUSTOM_BUTTONS import AddToReport
@@ -30,6 +30,7 @@ from .CUSTOM_BUTTONS import EditReport
 from .CUSTOM_BUTTONS import EraseButton
 from .CUSTOM_BUTTONS import HelpButton
 from .CUSTOM_BUTTONS import NoButton
+from .CUSTOM_BUTTONS import OKButton
 from .CUSTOM_BUTTONS import QuitButton
 from .CUSTOM_BUTTONS import RemoveFromReport
 from .CUSTOM_BUTTONS import SaveButton
@@ -37,6 +38,12 @@ from .CUSTOM_BUTTONS import YesButton
 
 from .CUSTOM_FRAMES import CollapsableFrame
 from .CUSTOM_FRAMES import ScrollableFrame
+from .CUSTOM_FRAMES import VCollapsableFrame
+from .CUSTOM_FRAMES import BorderFrame
+
+from .LED_BUTTONS import CheckLedButton
+from .LED_BUTTONS import LedButton
+from .LED_BUTTONS import RadioLedButton
 
 from .MESSAGE_BOX_WIDGETS import OkCancelBox
 from .MESSAGE_BOX_WIDGETS import ProgressBar
@@ -45,3 +52,5 @@ from .MESSAGE_BOX_WIDGETS import TimedBox
 from .MESSAGE_BOX_WIDGETS import Tooltip
 from .MESSAGE_BOX_WIDGETS import WarningBox
 from .MESSAGE_BOX_WIDGETS import YesNoBox
+
+from .SCRIPTS import *
